@@ -147,6 +147,9 @@ bit_read_BL(Bit_Chain *dat);
 void
 bit_write_BL(Bit_Chain *dat, BITCODE_BL value);
 
+void
+bit_write_BLd(Bit_Chain * dat, BITCODE_BLd value);
+
 BITCODE_BS
 bit_read_BOT(Bit_Chain *dat);
 
@@ -160,6 +163,8 @@ bit_read_3BLL(Bit_Chain *dat); /*unused but as documented*/
 
 void
 bit_write_BLL(Bit_Chain *dat, BITCODE_BLL value);
+void
+bit_write_3BLL(Bit_Chain * dat, BITCODE_BLL value);
 
 BITCODE_BD
 bit_read_BD(Bit_Chain *dat);
@@ -267,10 +272,16 @@ void
 bit_write_TIMEBLL(Bit_Chain *dat, BITCODE_TIMEBLL value);
 
 void
-bit_read_CMC(Bit_Chain *dat, Dwg_Color* color);
+bit_read_CMC(Bit_Chain *restrict dat, Dwg_Color *restrict color);
 
 void
-bit_write_CMC(Bit_Chain *dat, Dwg_Color* color);
+bit_write_CMC(Bit_Chain *restrict dat, Dwg_Color *restrict color);
+
+void
+bit_read_EMC(Bit_Chain *restrict dat, Dwg_Color *restrict color);
+
+void
+bit_write_EMC(Bit_Chain *restrict dat, Dwg_Color *restrict color);
 
 int
 bit_search_sentinel(Bit_Chain *dat, unsigned char sentinel[16]);
@@ -284,6 +295,13 @@ bit_chain_alloc(Bit_Chain *dat);
 void
 bit_print(Bit_Chain *dat, long unsigned int size);
 
+void
+bit_write_bits(Bit_Chain *restrict dat, const char *restrict bits);
+void
+bit_print_bits(unsigned char* bits, long unsigned int size);
+void
+bit_fprint_bits(FILE* fp, unsigned char* bits, long unsigned int size);
+
 void
 bit_explore_chain(Bit_Chain *dat, long unsigned int size);
 
